package com.ruoyi.bst.device.service.impl;

import java.util.List;
import java.util.Objects;

import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import com.ruoyi.bst.device.domain.DeviceVO;
import com.ruoyi.bst.device.service.DeviceAssembler;
import com.ruoyi.bst.gateway.domain.enums.GatewayOnlineStatus;
import com.ruoyi.bst.gatewayDevice.domain.GatewayDeviceQuery;
import com.ruoyi.bst.gatewayDevice.domain.vo.GatewayStatusCountGroupByDeviceVO;
import com.ruoyi.bst.gatewayDevice.service.GatewayDeviceDashboard;
import com.ruoyi.common.utils.collection.CollectionUtils;

@Service
public class DeviceAssemblerImpl implements DeviceAssembler {

    @Autowired
    private GatewayDeviceDashboard gatewayDeviceDashboard;

    @Override
    public void assembleGatewayCount(List<DeviceVO> list) {
        if (CollectionUtils.isEmptyElement(list)) {
            return;
        }

        GatewayDeviceQuery query = new GatewayDeviceQuery();
        query.setDeviceIds(CollectionUtils.map(list, DeviceVO::getId));
        List<GatewayStatusCountGroupByDeviceVO> statusList = gatewayDeviceDashboard.selectGatewayStatusCountGroupByDevice(query);

        for (DeviceVO device : list) {
            // 在线网关数
            GatewayStatusCountGroupByDeviceVO onlineStatus = statusList.stream()
                .filter(status -> Objects.equals(status.getDeviceId(), device.getId()) 
                    && GatewayOnlineStatus.ONLINE.getCode().equals(status.getGatewayOnlineStatus()))
                .findFirst().orElse(null);
            if (onlineStatus != null) {
                device.setOnlineGatewayCount(onlineStatus.getCount());
            } else {
                device.setOnlineGatewayCount(0);
            }

            // 离线网关数
            GatewayStatusCountGroupByDeviceVO offlineStatus = statusList.stream()
                .filter(status -> Objects.equals(status.getDeviceId(), device.getId()) 
                    && GatewayOnlineStatus.OFFLINE.getCode().equals(status.getGatewayOnlineStatus()))
                .findFirst().orElse(null);
            if (offlineStatus != null) {
                device.setOfflineGatewayCount(offlineStatus.getCount());
            } else {
                device.setOfflineGatewayCount(0);
            }
        }
    }

}
