package com.ruoyi.bst.device.service.impl;

import java.util.List;

import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import com.github.pagehelper.PageHelper;
import com.ruoyi.bst.device.domain.dto.DeviceSendDTO;
import com.ruoyi.bst.device.service.DeviceIotService;
import com.ruoyi.bst.gateway.service.GatewayIotService;
import com.ruoyi.bst.gatewayDevice.domain.GatewayDeviceQuery;
import com.ruoyi.bst.gatewayDevice.domain.GatewayDeviceVO;
import com.ruoyi.bst.gatewayDevice.service.GatewayDeviceService;
import com.ruoyi.common.utils.ServiceUtil;
import com.ruoyi.common.utils.StringUtils;
import com.ruoyi.common.utils.collection.CollectionUtils;
import com.ruoyi.iot.domain.response.CommandResponse;
import com.ruoyi.iot.util.IotUtil;

@Service
public class DeviceIotServiceImpl implements DeviceIotService {

    @Autowired
    private GatewayIotService gatewayIotService;

    @Autowired
    private GatewayDeviceService gatewayDeviceService;

    @Override
    public CommandResponse autoSend(DeviceSendDTO dto) {
        ServiceUtil.assertion(dto == null, "参数不能为空");
        ServiceUtil.assertion(StringUtils.isBlank(dto.getMac()), "mac不能为空");
        ServiceUtil.assertion(StringUtils.isBlank(dto.getCommand()), "命令不能为空");

        // 尝试次数（默认1次）
        int tryCount = dto.getTryCount() == null ? 1 : dto.getTryCount();

        // 查询设备关联的网关
        PageHelper.startPage(1, tryCount);
        // 排序优先级 最近心跳时间 > 网关最近在线时间 > 网关在线状态 
        PageHelper.orderBy("last_heart_time desc, gateway_last_online_time desc, gateway_online_status desc");
        GatewayDeviceQuery query = new GatewayDeviceQuery();
        query.setEqDeviceMac(dto.getMac());
        List<GatewayDeviceVO> gatewayDeviceList = gatewayDeviceService.selectGatewayDeviceList(query);

        // 发送命令
        CommandResponse res = null;
        ServiceUtil.assertion(CollectionUtils.isEmpty(gatewayDeviceList), "当前设备未关联网关");
        for (GatewayDeviceVO vo : gatewayDeviceList) {
            res = gatewayIotService.send(vo.getGatewayMac(), vo.getDeviceMac(), dto.getCommand(), dto.getTimeout());
            // 若发送成功，则直接返回
            if (IotUtil.isSubSuccess(res)) {
                break;
            }
        }
        return res;
    }


}
