package com.ruoyi.bst.gatewayDevice.service.impl;

import java.util.Collections;
import java.util.List;

import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import com.ruoyi.bst.gatewayDevice.domain.GatewayDevice;
import com.ruoyi.bst.gatewayDevice.domain.GatewayDeviceQuery;
import com.ruoyi.bst.gatewayDevice.domain.GatewayDeviceVO;
import com.ruoyi.bst.gatewayDevice.mapper.GatewayDeviceMapper;
import com.ruoyi.bst.gatewayDevice.service.GatewayDeviceService;
import com.ruoyi.common.utils.DateUtils;
import com.ruoyi.common.utils.ServiceUtil;
import com.ruoyi.common.utils.collection.CollectionUtils;

/**
 * 网关设备Service业务层处理
 *
 * @author ruoyi
 * @date 2025-04-17
 */
@Service
public class GatewayDeviceServiceImpl implements GatewayDeviceService
{
    @Autowired
    private GatewayDeviceMapper gatewayDeviceMapper;

    /**
     * 查询网关设备
     *
     * @param id 网关设备主键
     * @return 网关设备
     */
    @Override
    public GatewayDeviceVO selectGatewayDeviceById(Long id)
    {
        return gatewayDeviceMapper.selectGatewayDeviceById(id);
    }

    /**
     * 查询网关设备列表
     *
     * @param gatewayDevice 网关设备
     * @return 网关设备
     */
    @Override
    public List<GatewayDeviceVO> selectGatewayDeviceList(GatewayDeviceQuery gatewayDevice)
    {
        return gatewayDeviceMapper.selectGatewayDeviceList(gatewayDevice);
    }

    /**
     * 新增网关设备
     *
     * @param gatewayDevice 网关设备
     * @return 结果
     */
    @Override
    public int insertGatewayDevice(GatewayDevice gatewayDevice)
    {
        gatewayDevice.setCreateTime(DateUtils.getNowDate());
        return gatewayDeviceMapper.insertGatewayDevice(gatewayDevice);
    }

    /**
     * 修改网关设备
     *
     * @param gatewayDevice 网关设备
     * @return 结果
     */
    @Override
    public int updateGatewayDevice(GatewayDevice gatewayDevice)
    {
        return gatewayDeviceMapper.updateGatewayDevice(gatewayDevice);
    }

    /**
     * 批量删除网关设备
     *
     * @param ids 需要删除的网关设备主键
     * @return 结果
     */
    @Override
    public int deleteGatewayDeviceByIds(Long[] ids)
    {
        return gatewayDeviceMapper.deleteGatewayDeviceByIds(ids);
    }

    /**
     * 删除网关设备信息
     *
     * @param id 网关设备主键
     * @return 结果
     */
    @Override
    public int deleteGatewayDeviceById(Long id)
    {
        return gatewayDeviceMapper.deleteGatewayDeviceById(id);
    }

    @Override
    public List<GatewayDeviceVO> selectByGatewayMacList(List<String> gatewayMacList) {
        if (CollectionUtils.isEmptyElement(gatewayMacList)) {
            return Collections.emptyList();
        }
        GatewayDeviceQuery query = new GatewayDeviceQuery();
        query.setGatewayMacList(gatewayMacList);
        return gatewayDeviceMapper.selectGatewayDeviceList(query);
    }

    @Override
    public int insertOrUpdate(GatewayDevice data) {
        if (data == null) {
            return 0;
        }
        int rows = 0;
        try {
            // 尝试插入，如果插入失败，则更新
            rows = this.insertGatewayDevice(data);
            ServiceUtil.assertion(rows != 1, "插入失败");
        } catch (Exception e) {
            // 更新
            rows = gatewayDeviceMapper.updateByGatewayAndDeviceMac(data);
            ServiceUtil.assertion(rows != 1, "更新失败");
        }
        return rows;
    }
}
