package com.ruoyi.iot.service.impl;


import java.time.LocalDateTime;

import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import com.ruoyi.bst.device.service.DeviceService;
import com.ruoyi.bst.dsLog.domain.DsLog;
import com.ruoyi.bst.dsLog.service.DsLogService;
import com.ruoyi.bst.gatewayDevice.domain.GatewayDevice;
import com.ruoyi.bst.gatewayDevice.service.GatewayDeviceService;
import com.ruoyi.common.core.redis.RedisCache;
import com.ruoyi.common.utils.DateUtils;
import com.ruoyi.common.utils.StringUtils;
import com.ruoyi.iot.domain.ReceiveMsg;
import com.ruoyi.iot.enums.ReceiveType;
import com.ruoyi.iot.service.IotReceiveService;
import com.ruoyi.iot.util.IotUtil;

import lombok.extern.slf4j.Slf4j;

/**
 * @author wjh
 * 2024/5/6
 */
@Service
@Slf4j
public class IotReceiveServiceImpl implements IotReceiveService {

    @Autowired
    private RedisCache redisCache;

    @Autowired
    private GatewayDeviceService gatewayDeviceService;

    @Autowired
    private DsLogService dsLogService;

    @Autowired
    private DeviceService deviceService;

    @Override
    public void handleReceive(ReceiveMsg msg) {
        if (msg == null) {
            return;
        }
        // 数据点推送
        if (ReceiveType.DATA_POINT.getType().equals(msg.getType())) {
            String dsId = msg.getDsId();
            if (IotUtil.isSubDevice(dsId)) {
                handleSubDevice(msg);
            }
        }
        // 生命周期
        else if (ReceiveType.DEVICE_STATUS.getType().equals(msg.getType())) {
        }
    }

    private void handleSubDevice(ReceiveMsg msg) {
        String gatewayMac = msg.getDevName();
        String dsId = msg.getDsId();
        Object value = msg.getValue();
        LocalDateTime at = DateUtils.toLocalDateTime(msg.getAt());

        // 获取设备MAC
        String prefix = dsId;
        // 判断dsId的倒数3、2位是否为ST，如果是，则查询相似的设备MAC
        if (IotUtil.isSubDevicePart(dsId)) {
            prefix = dsId.substring(0, 10);
        }
        String deviceMac = deviceService.selectOneMacByPrefix(prefix);
        if (StringUtils.isBlank(deviceMac)) {
            log.error("不存在前缀为{}的设备，无法存储日志", prefix);
            return;
        }

        // 存储日志
        DsLog dsLog = new DsLog();
        dsLog.setGatewayMac(gatewayMac);
        dsLog.setDeviceMac(deviceMac);
        dsLog.setAt(at);
        dsLog.setData(value.toString());
        dsLog.setDs(dsId);
        dsLogService.insertDsLog(dsLog);

        // 更新设备网关数据
        GatewayDevice gatewayDevice = new GatewayDevice();
        gatewayDevice.setGatewayMac(gatewayMac);
        gatewayDevice.setDeviceMac(deviceMac);
        gatewayDevice.setLastHeartTime(at);
        gatewayDevice.setHeartBeat(IotUtil.getHeartBeat(value));
        gatewayDeviceService.insertOrUpdate(gatewayDevice);
    }

}
