package com.ruoyi.web.bst;

import java.util.List;

import javax.servlet.http.HttpServletResponse;

import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;

import com.ruoyi.bst.dsLog.domain.DsLog;
import com.ruoyi.bst.dsLog.domain.DsLogQuery;
import com.ruoyi.bst.dsLog.domain.DsLogVO;
import com.ruoyi.bst.dsLog.service.DsLogService;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.core.page.TableDataInfo;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.common.utils.poi.ExcelUtil;

/**
 * 数据日志Controller
 *
 * @author ruoyi
 * @date 2025-04-18
 */
@RestController
@RequestMapping("/bst/dsLog")
public class DsLogController extends BaseController
{
    @Autowired
    private DsLogService dsLogService;

    /**
     * 查询数据日志列表
     */
    @PreAuthorize("@ss.hasPermi('bst:dsLog:list')")
    @GetMapping("/list")
    public TableDataInfo list(DsLogQuery query)
    {
        startPage();
        startOrderBy();
        List<DsLogVO> list = dsLogService.selectDsLogList(query);
        return getDataTable(list);
    }

    /**
     * 导出数据日志列表
     */
    @PreAuthorize("@ss.hasPermi('bst:dsLog:export')")
    @Log(title = "数据日志", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, DsLogQuery query)
    {
        List<DsLogVO> list = dsLogService.selectDsLogList(query);
        ExcelUtil<DsLogVO> util = new ExcelUtil<DsLogVO>(DsLogVO.class);
        util.exportExcel(response, list, "数据日志数据");
    }

    /**
     * 获取数据日志详细信息
     */
    @PreAuthorize("@ss.hasPermi('bst:dsLog:query')")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id)
    {
        return success(dsLogService.selectDsLogById(id));
    }

    /**
     * 新增数据日志
     */
    @PreAuthorize("@ss.hasPermi('bst:dsLog:add')")
    @Log(title = "数据日志", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody DsLog dsLog)
    {
        return toAjax(dsLogService.insertDsLog(dsLog));
    }

    /**
     * 修改数据日志
     */
    @PreAuthorize("@ss.hasPermi('bst:dsLog:edit')")
    @Log(title = "数据日志", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody DsLog dsLog)
    {
        return toAjax(dsLogService.updateDsLog(dsLog));
    }

    /**
     * 删除数据日志
     */
    @PreAuthorize("@ss.hasPermi('bst:dsLog:remove')")
    @Log(title = "数据日志", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids)
    {
        return toAjax(dsLogService.deleteDsLogByIds(ids));
    }
}
