package com.ruoyi.web.bst;

import java.util.List;

import javax.servlet.http.HttpServletResponse;

import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;

import com.ruoyi.bst.gatewayDevice.domain.GatewayDevice;
import com.ruoyi.bst.gatewayDevice.domain.GatewayDeviceQuery;
import com.ruoyi.bst.gatewayDevice.domain.GatewayDeviceVO;
import com.ruoyi.bst.gatewayDevice.service.GatewayDeviceService;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.core.page.TableDataInfo;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.common.utils.poi.ExcelUtil;

/**
 * 网关设备Controller
 *
 * @author ruoyi
 * @date 2025-04-17
 */
@RestController
@RequestMapping("/bst/gatewayDevice")
public class GatewayDeviceController extends BaseController
{
    @Autowired
    private GatewayDeviceService gatewayDeviceService;

    /**
     * 查询网关设备列表
     */
    @PreAuthorize("@ss.hasPermi('bst:gatewayDevice:list')")
    @GetMapping("/list")
    public TableDataInfo list(GatewayDeviceQuery query)
    {
        startPage();
        startOrderBy();
        List<GatewayDeviceVO> list = gatewayDeviceService.selectGatewayDeviceList(query);
        return getDataTable(list);
    }

    /**
     * 导出网关设备列表
     */
    @PreAuthorize("@ss.hasPermi('bst:gatewayDevice:export')")
    @Log(title = "网关设备", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, GatewayDeviceQuery query)
    {
        List<GatewayDeviceVO> list = gatewayDeviceService.selectGatewayDeviceList(query);
        ExcelUtil<GatewayDeviceVO> util = new ExcelUtil<GatewayDeviceVO>(GatewayDeviceVO.class);
        util.exportExcel(response, list, "网关设备数据");
    }

    /**
     * 获取网关设备详细信息
     */
    @PreAuthorize("@ss.hasPermi('bst:gatewayDevice:query')")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id)
    {
        return success(gatewayDeviceService.selectGatewayDeviceById(id));
    }

    /**
     * 新增网关设备
     */
    @PreAuthorize("@ss.hasPermi('bst:gatewayDevice:add')")
    @Log(title = "网关设备", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody GatewayDevice gatewayDevice)
    {
        return toAjax(gatewayDeviceService.insertGatewayDevice(gatewayDevice));
    }

    /**
     * 修改网关设备
     */
    @PreAuthorize("@ss.hasPermi('bst:gatewayDevice:edit')")
    @Log(title = "网关设备", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody GatewayDevice gatewayDevice)
    {
        return toAjax(gatewayDeviceService.updateGatewayDevice(gatewayDevice));
    }

    /**
     * 删除网关设备
     */
    @PreAuthorize("@ss.hasPermi('bst:gatewayDevice:remove')")
    @Log(title = "网关设备", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids)
    {
        return toAjax(gatewayDeviceService.deleteGatewayDeviceByIds(ids));
    }
}
